Token

Enum Token 

pub enum Token {
Show 113 variants Illegal, Identifier(Vec<char>), LeftBracket, RightBracket, LeftParenthesis, RightParenthesis, LeftBrace, RightBrace, Dot, Spread, Semicolon, Colon, Comma, QuestionMark, OptionalChain, LessThan, LessEquals, MoreThan, MoreEquals, Equals, NotEquals, StrictEquals, NotStrictEquals, Addition, AdditionAssign, Subtraction, SubtractionAssign, Multiplication, MultiplicationAssign, Exponentiation, ExponentiationAssign, Division, DivisionAssign, Modulus, ModulusAssign, LogicalNot, LogicalAnd, LogicalAndAssign, LogicalOr, LogicalOrAssign, NullishCoalescing, NullishCoalescingAssign, BitwiseAnd, BitwiseAndAssign, BitwiseOr, BitwiseOrAssign, BitwiseXOR, BitwiseXORAssign, BitwiseNot, BitwiseNotAssign, RightShift, RightShiftAssign, UnsignedRightShift, UnsignedRightShiftAssign, LeftShift, LeftShiftAssign, Assign, Arrow, Await, Break, Case, Catch, Class, Const, Continue, Debugger, Default, Delete, Do, Else, Enum, Export, Extends, False, Finally, For, Function, If, Import, In, InstanceOf, New, Null, Return, Super, Switch, This, Throw, True, Try, TypeOf, Var, Void, While, With, Yield, Let, Static, Implements, Interface, Package, Private, Protected, Public, As, Async, From, Get, Meta, Of, Set, Target, EndOfFile,
}

Variants



Illegal



Identifier(Vec<char>)



LeftBracket



RightBracket



LeftParenthesis



RightParenthesis



LeftBrace



RightBrace



Dot



Spread



Semicolon



Colon



Comma



QuestionMark



OptionalChain



LessThan



LessEquals



MoreThan



MoreEquals



Equals



NotEquals



StrictEquals



NotStrictEquals



Addition



AdditionAssign



Subtraction



SubtractionAssign



Multiplication



MultiplicationAssign



Exponentiation



ExponentiationAssign



Division



DivisionAssign



Modulus



ModulusAssign



LogicalNot



LogicalAnd



LogicalAndAssign



LogicalOr



LogicalOrAssign



NullishCoalescing



NullishCoalescingAssign



BitwiseAnd



BitwiseAndAssign



BitwiseOr



BitwiseOrAssign



BitwiseXOR



BitwiseXORAssign



BitwiseNot



BitwiseNotAssign



RightShift



RightShiftAssign



UnsignedRightShift



UnsignedRightShiftAssign



LeftShift



LeftShiftAssign



Assign



Arrow



Await



Break



Case



Catch



Class



Const



Continue



Debugger



Default



Delete



Do



Else



Enum



Export



Extends



False



Finally



For



Function



If



Import



In



InstanceOf



New



Null



Return



Super



Switch



This



Throw



True



Try



TypeOf



Var



Void



While



With



Yield



Let



Static



Implements



Interface



Package



Private



Protected



Public



As



Async



From



Get



Meta



Of



Set



Target



EndOfFile